@@ -1,4 +1,5 @@
 import numbers
+import pickle
 from binascii import hexlify, unhexlify
 
 import pytest
@@ -14,6 +15,20 @@ def test_from_int(value):
     assert mpi == mpi
 
 
+@pytest.mark.parametrize("repr_", (repr, str), ids=lambda f: f.__name__)
+def test_repr(repr_):
+    assert isinstance(repr_(MPI(69)), str)
+
+
+def test_pickle():
+    value = MPI(1337)
+    assert value == pickle.loads(pickle.dumps(value))
+
+
+def test_hash():
+    assert isinstance(hash(MPI(1337)), int)
+
+
 def test_is_integral():
     assert isinstance(MPI(42), numbers.Integral)
 
