@@ -1,4 +1,5 @@
 import datetime as dt
+import pickle
 
 import certifi
 import pytest
@@ -49,7 +50,9 @@ def subject_key():
 
 
 class _X509Base:
-    # Derive and provide `x509`.
+    @pytest.fixture
+    def x509(self):
+        raise NotImplementedError
 
     @pytest.fixture
     def der(self, x509):
@@ -61,6 +64,16 @@ class _X509Base:
 
 
 class _CommonTests(_X509Base):
+    @pytest.mark.parametrize("repr_", (repr, str), ids=lambda f: f.__name__)
+    def test_repr(self, repr_, x509):
+        assert isinstance(repr_(x509), str)
+
+    def test_pickle(self, x509):
+        assert x509 == pickle.loads(pickle.dumps(x509))
+
+    def test_hash(self, x509):
+        assert isinstance(hash(x509), int)
+
     def test_from_buffer(self, x509, der):
         assert type(x509).from_buffer(der) == x509
 
